%define __lciover   v02-22-02
%define __hepmc3ver 3.3.0
%define __stdhepver stdhep-5-06-01
%define __fastjetver 3.4.3
%define __pythia8ver v8.312
%define __rootver 6.34.00
Name:           whizard
Version:        3.1.5
Release: 	14%{?dist}3a
Summary:        The Generator of Monte Carlo Event Generators for LHC, ILC, CLIC, and other HEP Experiments
Group:          Application/Science
License:        GPL
URL:            http://whizard.hepforge.org/
Source0:        http://www.hepforge.org/archive/whizard/whizard-%{version}.tar.gz
Patch0:         localhost:/%{name}-3.1.3-shared_ptr.patch
BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: ocaml gcc
BuildRequires: lcio >= %(echo %{__lciover} | sed -e 's;v\([0-9]\{1,\}\)-\([0-9]\{1,\}\)-\([0-9]\{1,\}\);\1.\2.\3;')
BuildRequires: HepMC3 >= %{__hepmc3ver}
BuildRequires: stdhep >= %(echo %{__stdhepver} | sed -e 's;stdhep-\([0-9]\{1,\}\)-\([0-9]\{1,\}\)-\([0-9]\{1,\}\);\1.\2.\3;')
BuildRequires: fastjet >= %{__fastjetver}
BuildRequires: pythia8 >= %(echo %{__pythia8ver} | sed -e 's;v8\.\(.*\);\1;')
BuildRequires: root >= %{__rootver}
%define __prefix	/opt/%{name}/%{name}-%{version}
Prefix: %{__prefix}

%description
WHIZARD is a program system designed for the efficient calculation of multi-particle scattering cross sections and simulated event samples.

Tree-level matrix elements are generated automatically for arbitrary partonic processes by using the Optimized Matrix Element Generator O'Mega. Matrix elements obtained by alternative methods (e.g., including loop corrections) may be interfaced as well. The program is able to calculate numerically stable signal and background cross sections and generate unweighted event samples with reasonable efficiency for processes with up to eight final-state particles; more particles are possible. For more particles, there is the option to generate processes as decay cascades including complete spin correlations.

Polarization is treated exactly for both the initial and final states. Final-state quark or lepton flavors can be summed over automatically where needed. For hadron collider physics, an interface to the standard LHAPDF is provided. For Linear Collider physics, beamstrahlung (CIRCE) and ISR spectra are included for electrons and photons. The events can be written to file in standard formats, including ASCII, STDHEP, the Les Houches event format (LHEF) or HepMC. These event files can then be showered and hadronized.

Currently, WHIZARD supports the Standard Model (optionally, with anomalous couplings), the MSSM, the NMSSM, Little Higgs models, Z' models, UED, and supports gravitinos and gravitons. Model extensions or completely different models can be added. There is also an interface to FeynRules.

%prep
%setup -n %{name}-%{version}
%patch 0 -p1 -b .shared_ptr

%build
# make root available
source `rpm -ql root | grep thisroot.sh | tail -1`
# Dirty hack to work around missing greadlink ####
%ifos darwin
mkdir tempbin
ln -s /usr/bin/readlink tempbin/greadlink
export PATH=$PATH:`pwd`/tempbin
%endif
#### end dirty hack ##############################

LIBS='-L/opt/osxws/lib -lgfortran' \
CXX=clang++ \
CXXFLAGS='-std=c++17' \
CFLAGS='-Wno-incompatible-pointer-types' \
PYTHON_VERSION=3.11 \
./configure \
    --prefix %{__prefix} FC=gfortran FCFLAGS="-g -O3" \
    --enable-fastjet \
    --enable-stdhep \
    --enable-hepmc \
    --enable-lcio \
    --enable-pythia6 \
    --enable-pythia8 \
    --with-rootsys=/opt/root/%{__rootver} \
    --with-fastjet=/opt/fastjet/%{__fastjetver} \
    --with-hepmc=/opt/HepMC3/%{__hepmc3ver} \
    --with-pythia8=/opt/pythia/%{__pythia8ver} \
    LCIO_DIR=/opt/lcio/%{__lciover}
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT

export PATH=$PATH:/opt/HepMC3/%{__hepmc3ver}/bin
export PATH=$PATH:/opt/fastjet/%{__fastjetver}/bin
# Dirty hack to work around missing greadlink ####
%ifos darwin
export PATH=$PATH:`pwd`/tempbin
%endif
#### end dirty hack ##############################

make install \
     DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,wheel,-)
%dir %{__prefix}
%{__prefix}/*

%doc AUTHORS BUGS COPYING ChangeLog NEWS README

%changelog
* Tue Dec 24 2024 Keisuke Fujii <keisuke.fujii@kek.jp> - 3.1.5-14hepx3a
- 1st release on MacOS 14
- with fjcontribu updated from 1.053 to 1.100
- built with OSXWS 14 and gcc and clang++

* Tue Nov 7 2023 Keisuke Fujii <keisuke.fujii@kek.jp> - 3.1.3-13hepx2b
- 2nd release on MacOS 13
- with fjcontribu updated from 1.048 to 1.053
- built with OSXWS 13 and clang

* Mon Nov 6 2023 Keisuke Fujii <keisuke.fujii@kek.jp> - 3.1.3-13hepx2a
- 1st release on MacOS 13
- added shared_ptr patch
- built with OSXWS 13 and clang

* Wed Aug 24 2022 Keisuke Fujii <keisuke.fujii@kek.jp> - 3.0.2-12hepx2c
- 3rd release on MacOS 12 for M1 Macs
- modified to explicitly link libgfortran
- built with OSXWS 12beta and clang

* Sun Feb 27 2022 Keisuke Fujii <keisuke.fujii@kek.jp> - 3.0.2-12hepx2b
- 2nd release on MacOS 12 for M1 Macs
- built with OSXWS 12beta and clang

* Thu Feb 24 2022 Keisuke Fujii <keisuke.fujii@kek.jp> - 3.0.2-12hepx2a
- 1st release on MacOS 12 for M1 Macs
- built with OSXWS 11 and clang

* Wed Jan 29 2020 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.8.2-10.15hepx1a
- 1st release on MacOS X 10.15
- built with OSXWS 10.15

* Sun Dec 29 2019 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.8.2-10.14hepx1a
- 1st release on MacOS X 10.14
- added stdhep, HepMC3, lcio, and fastjet support.
- built with OSXWS 10.14

* Sat Dec 28 2019 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.6.3-10.14hepx1b
- 2nd release on MacOS X 10.14
- built with OSXWS 10.14

* Tue Dec 25 2018 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.6.3-10.14hepx1a
- 1st release on MacOS X 10.14
- built with OSXWS 10.13

* Wed Apr 04 2018 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.6.3-10.13hepx1a
- 1st release on MacOS X 10.13
- built with OSXWS 10.13

* Mon Dec 26 2016 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.2.8-10.12hepx1b
- 2nd release on MacOS X 10.12
- built with OSXWS 10.12

* Mon Dec 19 2016 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.2.8-10.12hepx1a
- 1st release on MacOS X 10.12
- built with OSXWS 10.11

* Tue Feb 09 2016 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.2.8-10.11hepx1a
- 1st release on MacOS X 10.11

* Wed Dec 24 2014 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.2.2-10.10hepx1a
- 1st release on MacOS X 10.10

* Thu Aug 07 2014 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.2.2-10.9hepx1a
- 1st release on MacOS X 10.9

* Sat Nov 30 2013 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.1.1-10.9hepx1a
- 1st release on MacOS X 10.9

* Fri Jun 22 2012 Keisuke Fujii <keisuke.fujii@kek.jp> - 2.1.0-10.7hepx1a
- 1st release on MacOS X 
